All of lore.kernel.org
 help / color / mirror / Atom feed
From: "Marc-André Lureau" <marcandre.lureau@redhat.com>
To: qemu-devel@nongnu.org
Cc: pbonzini@redhat.com, berrange@redhat.com, ehabkost@redhat.com,
	"Marc-André Lureau" <marcandre.lureau@redhat.com>
Subject: [PATCH 13/26] object: rename link "child" to "target"
Date: Sun,  1 Dec 2019 15:15:18 +0400	[thread overview]
Message-ID: <20191201111531.1136947-14-marcandre.lureau@redhat.com> (raw)
In-Reply-To: <20191201111531.1136947-1-marcandre.lureau@redhat.com>

A child property is a different kind of property. Let's use "target"
for the link target.

Signed-off-by: Marc-André Lureau <marcandre.lureau@redhat.com>
---
 include/qom/object.h |  4 ++--
 qom/object.c         | 24 ++++++++++++------------
 2 files changed, 14 insertions(+), 14 deletions(-)

diff --git a/qom/object.c b/qom/object.c
index 7e42fa0d99..6f3800c693 100644
--- a/qom/object.c
+++ b/qom/object.c
@@ -1696,7 +1696,7 @@ void object_property_allow_set_link(const Object *obj, const char *name,
 }
 
 typedef struct {
-    Object **child;
+    Object **targetp;
     void (*check)(const Object *, const char *, Object *, Error **);
     ObjectPropertyLinkFlags flags;
 } LinkProperty;
@@ -1706,11 +1706,11 @@ static void object_get_link_property(Object *obj, Visitor *v,
                                      Error **errp)
 {
     LinkProperty *lprop = opaque;
-    Object **child = lprop->child;
+    Object **targetp = lprop->targetp;
     gchar *path;
 
-    if (*child) {
-        path = object_get_canonical_path(*child);
+    if (*targetp) {
+        path = object_get_canonical_path(*targetp);
         visit_type_str(v, name, &path, errp);
         g_free(path);
     } else {
@@ -1765,8 +1765,8 @@ static void object_set_link_property(Object *obj, Visitor *v,
 {
     Error *local_err = NULL;
     LinkProperty *prop = opaque;
-    Object **child = prop->child;
-    Object *old_target = *child;
+    Object **targetp = prop->targetp;
+    Object *old_target = *targetp;
     Object *new_target = NULL;
     char *path = NULL;
 
@@ -1788,7 +1788,7 @@ static void object_set_link_property(Object *obj, Visitor *v,
         return;
     }
 
-    *child = new_target;
+    *targetp = new_target;
     if (prop->flags & OBJ_PROP_LINK_STRONG) {
         object_ref(new_target);
         object_unref(old_target);
@@ -1799,7 +1799,7 @@ static Object *object_resolve_link_property(Object *parent, void *opaque, const
 {
     LinkProperty *lprop = opaque;
 
-    return *lprop->child;
+    return *lprop->targetp;
 }
 
 static void object_release_link_property(Object *obj, const char *name,
@@ -1807,14 +1807,14 @@ static void object_release_link_property(Object *obj, const char *name,
 {
     LinkProperty *prop = opaque;
 
-    if ((prop->flags & OBJ_PROP_LINK_STRONG) && *prop->child) {
-        object_unref(*prop->child);
+    if ((prop->flags & OBJ_PROP_LINK_STRONG) && *prop->targetp) {
+        object_unref(*prop->targetp);
     }
     g_free(prop);
 }
 
 void object_property_add_link(Object *obj, const char *name,
-                              const char *type, Object **child,
+                              const char *type, Object **targetp,
                               void (*check)(const Object *, const char *,
                                             Object *, Error **),
                               ObjectPropertyLinkFlags flags,
@@ -1825,7 +1825,7 @@ void object_property_add_link(Object *obj, const char *name,
     gchar *full_type;
     ObjectProperty *op;
 
-    prop->child = child;
+    prop->targetp = targetp;
     prop->check = check;
     prop->flags = flags;
 
diff --git a/include/qom/object.h b/include/qom/object.h
index 03574473cd..0ac1a9acca 100644
--- a/include/qom/object.h
+++ b/include/qom/object.h
@@ -1526,7 +1526,7 @@ void object_property_allow_set_link(const Object *, const char *,
  * @obj: the object to add a property to
  * @name: the name of the property
  * @type: the qobj type of the link
  * @child: a pointer to where the link object reference is stored
  * @check: callback to veto setting or NULL if the property is read-only
  * @flags: additional options for the link
  * @errp: if an error occurs, a pointer to an area to store the error
@@ -1551,7 +1551,7 @@ void object_property_allow_set_link(const Object *, const char *,
  * modified.
  */
 void object_property_add_link(Object *obj, const char *name,
-                              const char *type, Object **child,
+                              const char *type, Object **targetp,
                               void (*check)(const Object *obj, const char *name,
                                             Object *val, Error **errp),
                               ObjectPropertyLinkFlags flags,
@@ -1526,7 +1526,7 @@ void object_property_allow_set_link(const Object *, const char *,
  * @name: the name of the property
  * @type: the qobj type of the link
- * @child: a pointer to where the link object reference is stored
+ * @targetp: a pointer to where the link object reference is stored
  * @check: callback to veto setting or NULL if the property is read-only
  * @flags: additional options for the link
-- 
2.24.0



  parent reply	other threads:[~2019-12-01 11:29 UTC|newest]

Thread overview: 34+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2019-12-01 11:15 [PATCH 00/26] Make QDev use class properties Marc-André Lureau
2019-12-01 11:15 ` [PATCH 01/26] object: add extra sanity checks Marc-André Lureau
2019-12-01 19:33   ` Philippe Mathieu-Daudé
2019-12-01 11:15 ` [PATCH 02/26] qdev: remove duplicated qdev_property_add_static() doc Marc-André Lureau
2019-12-11 15:42   ` Damien Hedde
2019-12-01 11:15 ` [PATCH 03/26] qdev: remove extraneous error Marc-André Lureau
2019-12-11 16:53   ` Damien Hedde
2019-12-01 11:15 ` [PATCH 04/26] qdev: move helper function to monitor/misc Marc-André Lureau
2019-12-01 19:35   ` Philippe Mathieu-Daudé
2019-12-01 11:15 ` [PATCH 05/26] object: avoid extra class property key duplication Marc-André Lureau
2019-12-01 11:15 ` [PATCH 06/26] object: add class property initializer Marc-André Lureau
2019-12-01 11:15 ` [PATCH 07/26] object: add object_property_get_defaut() Marc-André Lureau
2019-12-01 11:15 ` [PATCH 08/26] object: make object_class_property_add* return property Marc-André Lureau
2019-12-01 11:15 ` [PATCH 09/26] qstring: add qstring_free() Marc-André Lureau
2019-12-01 11:15 ` [PATCH 10/26] object: add object_property_set_defaut_{bool, str, int, uint}() Marc-André Lureau
2019-12-01 11:15 ` [PATCH 11/26] object: do not free class properties Marc-André Lureau
2019-12-01 11:15 ` [PATCH 12/26] object: check strong flag with & Marc-André Lureau
2019-12-01 11:15 ` Marc-André Lureau [this message]
2019-12-01 11:15 ` [PATCH 14/26] object: add direct link flag Marc-André Lureau
2019-12-01 11:15 ` [PATCH 15/26] object: express const link with link property Marc-André Lureau
2019-12-01 11:15 ` [PATCH 16/26] object: add object_class_property_add_link() Marc-André Lureau
2019-12-01 11:15 ` [PATCH 17/26] object: release all props Marc-André Lureau
2019-12-01 11:15 ` [PATCH 18/26] object: return self in object_ref() Marc-André Lureau
2019-12-01 11:15 ` [PATCH 19/26] qdev: set properties with device_class_set_props() Marc-André Lureau
2019-12-01 11:15 ` [PATCH 20/26] qdev: move instance properties to class properties Marc-André Lureau
2019-12-01 11:15 ` [PATCH 21/26] qdev: register properties as " Marc-André Lureau
2019-12-01 11:15 ` [PATCH 22/26] vl: print default value in object help Marc-André Lureau
2019-12-01 11:15 ` [PATCH 23/26] qom: simplify qmp_device_list_properties() Marc-André Lureau
2019-12-01 11:15 ` [PATCH 24/26] qom: introduce object_property_help() Marc-André Lureau
2019-12-01 11:15 ` [PATCH 25/26] qapi/qmp: add ObjectPropertyInfo.default-value Marc-André Lureau
2019-12-11 16:06   ` Eric Blake
2019-12-11 17:41     ` Marc-André Lureau
2019-12-01 11:15 ` [PATCH 26/26] qdev: use object_property_help() Marc-André Lureau
2020-01-10 15:30 [PATCH 00/26] Various qom & qdev enhancements Marc-André Lureau
2020-01-10 15:30 ` [PATCH 13/26] object: rename link "child" to "target" Marc-André Lureau

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20191201111531.1136947-14-marcandre.lureau@redhat.com \
    --to=marcandre.lureau@redhat.com \
    --cc=berrange@redhat.com \
    --cc=ehabkost@redhat.com \
    --cc=pbonzini@redhat.com \
    --cc=qemu-devel@nongnu.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.